==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebRowDataEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDetailDescription } from "./WebRowDataEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowDataEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowDataEventArgsDetailDescriptionMetadata, _super);
    function WebRowDataEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowDataEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowDataEventArgsDetailDescriptionMetadata.a == null) {
            WebRowDataEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowDataEventArgsDetailDescriptionMetadata.c(WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowDataEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebRowDataEventArgsDetailDescriptionMetadata.a);
    };
    WebRowDataEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowDataEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Data", "Unknown");
        a.item("PrimaryKey", "Unknown");
    };
    WebRowDataEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowDataEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebRowDataEventArgsDetail", function () { return new WebRowDataEventArgsDetailDescription(); });
        a.ac("WebRowDataEventArgsDetail", WebRowDataEventArgsDetailDescriptionMetadata.a);
    };
    WebRowDataEventArgsDetailDescriptionMetadata.$t = markType(WebRowDataEventArgsDetailDescriptionMetadata, 'WebRowDataEventArgsDetailDescriptionMetadata');
    WebRowDataEventArgsDetailDescriptionMetadata.a = null;
    return WebRowDataEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowDataEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebRowDataEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDetailDescription } from "./WebRowDataEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowDataEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowDataEventArgsDetailDescriptionMetadata, _super);
    function WebRowDataEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowDataEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowDataEventArgsDetailDescriptionMetadata.a == null) {
            WebRowDataEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowDataEventArgsDetailDescriptionMetadata.c(WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowDataEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRowDataEventArgsDetailDescriptionMetadata.a);
    };
    WebRowDataEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowDataEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Data", "Unknown");
        a.item("RowData", "Unknown");
        a.item("PrimaryKey", "Unknown");
        a.item("RowKey", "Unknown");
    };
    WebRowDataEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowDataEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebRowDataEventArgsDetail", function () { return new WebRowDataEventArgsDetailDescription(); });
        a.ad("WebRowDataEventArgsDetail", WebRowDataEventArgsDetailDescriptionMetadata.a);
    };
    WebRowDataEventArgsDetailDescriptionMetadata.$t = markType(WebRowDataEventArgsDetailDescriptionMetadata, 'WebRowDataEventArgsDetailDescriptionMetadata');
    WebRowDataEventArgsDetailDescriptionMetadata.a = null;
    return WebRowDataEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowDataEventArgsDetailDescriptionMetadata };
